<?php

// Require json support
$dir = rtrim(dirname(__FILE__), '/').'/';
include_once($dir.'wfmjson.php');

// Only define the function if it doesn't already exist
if (!function_exists('wplocal')) {

	function wplocal($path = '', $mediabox = false, $tw = 100, $th = 100) {
		
		// Get the real path
		$path = rtrim($path, "/") . "/";
		$folder = realpath($path);
		
		// The local photos
		$local = array();
		
		// Turn off error reporting
		$ini = error_reporting(0);
		
		// If we opened the directory
		$files = @scandir($folder);
		if (!empty($files)) {
			
			// Loop over each file in the directory. We are looking for images and txt files
			// The text files are read in and used as the caption for the image
			foreach ($files as $file) {
				if ($file == '.' || $file == '..') continue;
				
				// Get the mime
				$src = $path.$file;
				$mime = getMimeType($src);
				
				// If the mime is an image type
				if (startsWith($mime, 'image/') && !wp_is_thumbnail($file)) {
					
					// The description
					$desc = $file;
					
					// The href for the image
					$href = $src;
					
					// Look for a text file with the same name
					$desc_path = realpath($src.'.txt');
					
					// Try uppercase extensions just in case
					// the lowercase txt doesn't exist
					if (!file_exists($desc_path)) {
						$desc_path = realpath($src.'.TXT');
					}
					
					if (file_exists($desc_path)) {
						
						// Open the file description
						$filehandle = @fopen($desc_path, 'r');
						
						// If opened
						if ($filehandle) {
							
							// Take the first 1k of characters and make it the description
							$desc = fgets($filehandle);
						}
						
						// If there is more to the file
						if (!feof($filehandle) and !$mediabox) {
							
							// Use the 2nd line as the href
							$href = fgets($filehandle);
						}
						
						// Close the file
						fclose($filehandle);
					}
					
					$thumbnail = wp_thumbnail($folder.'/'.$file, $tw, $th);
					$local[$src] = array('caption' => $desc, 'thumbnail' => ($thumbnail ? $path.$thumbnail : $src), 'href' => $href);
					//error_log('src: '.$src.' caption: '.$desc.' thumbnail: '.$src.' href: '.$href);
				}
			}
		}
		
		// Reset error reporting
		error_reporting($ini);
		
		// Return a json encoded string
		/*return json_encode($local);*/
		return $local;
	}
}

if (!function_exists('wp_thumbnail'))
{
	function wp_thumbnail($filename, $w, $h)
	{
		if (!wp_gd())
			return false;
			
		$real_path = realpath($filename);
		$result = wp_thumbnail_needed($real_path);
		if($result)
		{
			$result = wp_resample_image($real_path, $w, $h);
			if (!$result)
			{
				//echo ('error');
			}
		}
		else
		{
			//echo ('not needed');
		}
		return $result;
	}
}

if (!function_exists('wp_image_magik'))
{
	function wp_image_magik()
	{
		return class_exists('Imagick');
	}
}
if (!function_exists('wp_gd'))
{
	function wp_gd()
	{
		return extension_loaded('gd') && function_exists('gd_info');
	}
}

if (!function_exists('wp_image_from_file'))
{
	function wp_image_from_file($orig = '')
	{
		$mime = getMimeType($orig);
		$img = false;
		switch ($mime) {
		    case 'image/jpeg':
		        $img = @imagecreatefromjpeg($orig);
		        break;
		    case 'image/tiff':
		        //$img = @imagecreatefromgif($orig);
		        break;
			case 'image/png':
			    $img = @imagecreatefrompng($orig);
			   	break;
			case 'image/gif':
				$img = @imagecreatefromgif($orig);
				break;
			case 'image/bmp':
				$img = @imagecreatefromwbmp($orig);
				break;
			default:
				break;
		}
		
		return array($img, $mime);
	}
}
if (!function_exists('wp_save_image_to_file'))
{
	function wp_save_image_to_file($img, $dest, $mime = 'image/jpeg', $quality = 100)
	{
		$result = false;
		switch ($mime) {
		    case 'image/jpeg':
		        $result = @imagejpeg($img, $dest, $quality);
		        break;
		    case 'image/tiff':
		        break;
			case 'image/png':
			    $result = @imagepng($img, $dest, $quality%10);
			   	break;
			case 'image/gif':
				$result = @imagegif($img, $dest);
				break;
			case 'image/bmp':
				$result = @imagewbmp($img, $dest);
				break;
			default:
				break;
		}
		
		return $result;
	}
}

if (!function_exists('wp_resample_image'))
{
	function wp_resample_image($filename, $width, $height, $quality = 100)
	{
		// Get new dimensions
		list($width_orig, $height_orig) = getimagesize($filename);
	
		$ratio_orig = $width_orig/$height_orig;
	
		if ($width/$height > $ratio_orig) {
		   $width = $height*$ratio_orig;
		} else {
		   $height = $width/$ratio_orig;
		}
	
		// Resample
		$image_p = imagecreatetruecolor($width, $height);
		list($image, $mime) = wp_image_from_file($filename);
		
		$result = false;
		if ($image)
		{
			imagecopyresampled($image_p, $image, 0, 0, 0, 0, $width, $height, $width_orig, $height_orig);
			list($name, $ext) = wp_filename($filename);
			$mtime = wp_filemtime($filename);
			$dir = rtrim(dirname($filename), '/').'/';
			$thumbnail_name = $name.'-t-'.$mtime.'.'.$ext;
			$result = (wp_save_image_to_file($image_p, $dir.$thumbnail_name, $mime, $quality) ? $thumbnail_name : false);
		}

		return $result;
	}
}

if (!function_exists('wp_thumbnail_needed'))
{
	function wp_thumbnail_needed($orig)
	{
		if (!file_exists($orig))
			return false;
		
		list($filename, $ext) = wp_filename($orig);
		$mtime = wp_filemtime($orig);
		
		// Thumbnail format
		// original_name-t-modification_time.ext
		$thumbnail_name = $filename.'-t-';
		foreach (glob($thumbnail_name.'*.'.$ext) as $tname)
		{
			list($t_filename, $t_ext) = wp_filename($tname);
			$thumb_mtime = intval(end(explode('-', $t_filename)));
			if ($thumb_mtime == $mtime)
				return $tname;
			else
				@unlink($tname);
		}
		
		return true;
	}
}

if (!function_exists('wp_im_thumbnail'))
{
	function wp_im_thumbnail($orig, $w, $h)
	{
		$dpi = 72;
		
		$image = new Imagick(); 
		$image->readImage($orig); 
		$image->setImageResolution($w, $h); 
		$image->resampleImage(72, 72, imagick::FILTER_UNDEFINED, 0);
		
		$ext = pathinfo ($orig, PATHINFO_EXTENSION);
		$image->writeImage('image72-t-.'.$ext);
	}
}

if (!function_exists('wp_is_thumbnail'))
{
	function wp_is_thumbnail($orig)
	{
		$pathinfo = pathinfo($orig);
		$ext = $pathinfo['extension'];
		$filename = basename($orig, '.'.$ext);
		return strpos($filename, '-t-') !== false;
	}
}

if (!function_exists('wp_filemtime'))
{
	function wp_filemtime($file = '')
	{		
		return (@file_exists($file) ? @filemtime($file) : false);
	}
}

if (!function_exists('wp_filename'))
{
	function wp_filename($file = '')
	{
		// PHP pathinfo['filename'] is only available in 5.2+
		$pathinfo = pathinfo($file);
		$ext = $pathinfo['extension'];
		$filename = basename($file, '.'.$ext);
		return array($filename, $ext);
	}
}

// Only define the function if it doesn't already exist
if (!function_exists('getMimeType')) {
	function getMimeType($file){
		return is_dir($file) ? 'text/directory' : mime($file);
	}
}

// Only define the function if it doesn't already exist
if (!function_exists('mime')) {
	function mime($file, $options = array()){
	
		// Adding $mime declaration to avoid PHP warning
		$mime = '';
	
		// Below is implementation from filemananger 
		$file = realpath($file);
		$options = array_merge(array(
			'default' => null,
			'extension' => strtolower(pathinfo($file, PATHINFO_EXTENSION)),
		), $options);
	
		$ini = error_reporting(0);
		if (function_exists('finfo_open') && $f = finfo_open(FILEINFO_MIME, getenv('MAGIC'))){
			$mime = finfo_file($f, $file);
			finfo_close($f);
		}
		error_reporting($ini);
	
		if(!$mime && in_array($options['extension'], array('gif', 'jpg', 'jpeg', 'png'))){
			$image = getimagesize($file);
			if(!empty($image['mime']))
				$mime = $image['mime'];
		}
	
		if(!$mime && $options['default']) $mime = $options['default'];
	
		if((!$mime || $mime=='application/octet-stream') && $options['extension']){
			static $mimes;
			if(!$mimes) $mimes = parse_ini_file(pathinfo(__FILE__, PATHINFO_DIRNAME).'/MimeTypes.ini');
		
			if(!empty($mimes[$options['extension']])) return $mimes[$options['extension']];
		}
	
		return $mime;
	}
}

// For PHP 5.x support
// Author: Gregory Barchard
// February 23, 2010
// Based on work done at http://www.php.net/manual/en/function.pathinfo.php#88159
if (!function_exists('pathinfo_filename')) {
	function pathinfo_filename($file) { //file.name.ext, returns file.name

		// If the PATHINFO_FILENAME variable is defined, use it
	    if (defined('PATHINFO_FILENAME')) return pathinfo($file, PATHINFO_FILENAME);

		// Get the path info for the file
		$pathinfo = pathinfo($file);
	
		// Get the basename (filename.extension)
		$basename = $pathinfo['basename'];
	
		// Assume the filename to be the same as the basename
		$filename = $basename;
	
		// If an extension exists in the basename
	    if (strstr($basename, '.')) {
	
			// Split the filename off
			$filename = substr($basename, 0, strrpos($basename, '.'));
		}
	
		// Return the filename
		return $filename;
	}
}

if (!function_exists('startsWith')) {
	function startsWith($string, $look){
		return strpos($string, $look)===0;
	}
}

if (!function_exists('endsWith')) {
	function endsWith($string, $look){
		return strrpos($string, $look)===strlen($string)-strlen($look);
	}
}

if (!function_exists('getClosestValue'))
{
	// http://stackoverflow.com/questions/5464919/php-nearest-value-from-an-array
	function getClosestValue($search, $arr)
	{
	   $closest = null;
	   foreach($arr as $item)
	   {
	      if($closest == null || abs($search - $closest) > abs($item - $search))
	      {
	         $closest = $item;
	      }
	   }
	   return $closest;
	}
}

?>